Get version information about a pip from pypi (and private repos)

Installation
============

.. code-block:: bash
   :class: ignore

   pip3 install pip-versions


Usage
=====

Get the latest version

.. code-block:: bash
   :class: ignore

   pip-versions latest django


.. code-block:: bash
   :class: ignore

   3.1.2


Get all the versions

.. code-block:: bash
   :class: ignore

   pip-versions list django


.. code-block:: bash
   :class: ignore

   2.2.15
   2.2.16
   3.0
   3.0.1
   3.0.2
   3.0.3
   3.0.4
   3.0.5
   3.0.6
   3.0.7
   3.0.8
   3.0.9
   3.0.10
   3.1
   3.1.1
   3.1.2
